@@ -1,4 +1,4 @@
 quantile_if <- function(x, y, p)
 {
-    (x >= y) - p
+    as.numeric(x >= y) - p
 }
\ No newline at end of file
